Learn R Programming

hht (version 2.1.1)

EvolutiveFFT: Calculate the evolutive Fourier spectrogram.

Description

Generates the evolutive Fourier spectrogram of a signal, and returns it for use in FTGramImage.

Usage

EvolutiveFFT(sig, dt, ft, freq.span, taper = 0.05)

Arguments

Value

  • zPower spectrum
  • yFrequency
  • xTime
  • original.signalThe input signal
  • ttSample times based on input sample rate dt

item

  • freq.span
  • taper

Details

This is an internal function and users will likely not call it directly.

References

Jonathan M. Lees (2012). RSEIS: Seismic Time Series Analysis Tools. R package version 3.1-3.